@@ -1,4 +1,4 @@
-/* $Id: VBoxNetAdp-linux.c 142885 2021-02-20 17:51:01Z aleksey $ */
+/* $Id: VBoxNetAdp-linux.c 149586 2022-01-28 09:26:21Z vgalitsy $ */
 /** @file
  * VBoxNetAdp - Virtual Network Adapter Driver (Host), Linux Specific Code.
  */
@@ -66,6 +66,13 @@
 
 #define VBOXNETADP_FROM_IFACE(iface) ((PVBOXNETADP) ifnet_softc(iface))
 
+/** Set netdev MAC address. */
+#if RTLNX_VER_MIN(5,17,0)
+# define VBOX_DEV_ADDR_SET(dev, addr, len) dev_addr_mod(dev, 0, addr, len)
+#else /* < 5.17.0 */
+# define VBOX_DEV_ADDR_SET(dev, addr, len) memcpy(dev->dev_addr, addr, len)
+#endif
+
 
 /*********************************************************************************************************************************
 *   Internal Functions                                                                                                           *
@@ -303,7 +310,7 @@ int vboxNetAdpOsCreate(PVBOXNETADP pThis, PCRTMAC pMACAddress)
 
         if (pNetDev->dev_addr)
         {
-            memcpy(pNetDev->dev_addr, pMACAddress, ETH_ALEN);
+            VBOX_DEV_ADDR_SET(pNetDev, pMACAddress, ETH_ALEN);
             Log2(("vboxNetAdpOsCreate: pNetDev->dev_addr = %.6Rhxd\n", pNetDev->dev_addr));
 
             /*
