@@ -1,4 +1,4 @@
-/* $Id: memobj-r0drv-linux.c 147244 2021-10-04 15:42:27Z bird $ */
+/* $Id: memobj-r0drv-linux.c 150609 2022-03-21 21:07:44Z vgalitsy $ */
 /** @file
  * IPRT - Ring-0 Memory Objects, Linux.
  */
@@ -1964,7 +1964,7 @@ DECLHIDDEN(RTHCPHYS) rtR0MemObjNativeGetPagePhysAddr(PRTR0MEMOBJINTERNAL pMem, s
         case RTR0MEMOBJTYPE_PAGE:
         default:
             AssertMsgFailed(("%d\n", pMemLnx->Core.enmType));
-            /* fall thru */
+            RT_FALL_THROUGH();
 
         case RTR0MEMOBJTYPE_RES_VIRT:
             return NIL_RTHCPHYS;
