@@ -1,4 +1,4 @@
-/* $Id: the-linux-kernel.h 145161 2021-06-15 15:21:15Z vgalitsy $ */
+/* $Id: the-linux-kernel.h 151617 2022-05-27 12:57:24Z ramshankar $ */
 /** @file
  * IPRT - Include all necessary headers for the Linux kernel.
  */
@@ -184,6 +184,11 @@
 # include <asm/tlbflush.h>
 #endif
 
+/* for kernel_fpu_begin / kernel_fpu_end() */
+#if RTLNX_VER_MIN(4,2,0)
+# include <asm/fpu/api.h>
+#endif
+
 #if RTLNX_VER_MIN(3,7,0)
 # include <asm/smap.h>
 #else
